"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AvatarType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AvatarTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AvatarType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    AvatarTypeNone: _AvatarType.ValueType  # 0
    """"""
    AvatarTypeNFT: _AvatarType.ValueType  # 1
    """"""

class AvatarType(_AvatarType, metaclass=_AvatarTypeEnumTypeWrapper):
    """"""

AvatarTypeNone: AvatarType.ValueType  # 0
""""""
AvatarTypeNFT: AvatarType.ValueType  # 1
""""""
global___AvatarType = AvatarType

class _BubbleType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _BubbleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_BubbleType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    BubbleTypeNone: _BubbleType.ValueType  # 0
    """"""
    BubbleTypeClickButton: _BubbleType.ValueType  # 1
    """"""
    BubbleTypeDmSettingPanel: _BubbleType.ValueType  # 2
    """"""

class BubbleType(_BubbleType, metaclass=_BubbleTypeEnumTypeWrapper):
    """"""

BubbleTypeNone: BubbleType.ValueType  # 0
""""""
BubbleTypeClickButton: BubbleType.ValueType  # 1
""""""
BubbleTypeDmSettingPanel: BubbleType.ValueType  # 2
""""""
global___BubbleType = BubbleType

class _CheckboxType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CheckboxTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CheckboxType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CheckboxTypeNone: _CheckboxType.ValueType  # 0
    """"""
    CheckboxTypeEncourage: _CheckboxType.ValueType  # 1
    """"""
    CheckboxTypeColorDM: _CheckboxType.ValueType  # 2
    """"""

class CheckboxType(_CheckboxType, metaclass=_CheckboxTypeEnumTypeWrapper):
    """"""

CheckboxTypeNone: CheckboxType.ValueType  # 0
""""""
CheckboxTypeEncourage: CheckboxType.ValueType  # 1
""""""
CheckboxTypeColorDM: CheckboxType.ValueType  # 2
""""""
global___CheckboxType = CheckboxType

class _DMAttrBit:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DMAttrBitEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DMAttrBit.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DMAttrBitProtect: _DMAttrBit.ValueType  # 0
    """保护弹幕"""
    DMAttrBitFromLive: _DMAttrBit.ValueType  # 1
    """直播弹幕"""
    DMAttrHighLike: _DMAttrBit.ValueType  # 2
    """高赞弹幕"""

class DMAttrBit(_DMAttrBit, metaclass=_DMAttrBitEnumTypeWrapper):
    """弹幕属性位值"""

DMAttrBitProtect: DMAttrBit.ValueType  # 0
"""保护弹幕"""
DMAttrBitFromLive: DMAttrBit.ValueType  # 1
"""直播弹幕"""
DMAttrHighLike: DMAttrBit.ValueType  # 2
"""高赞弹幕"""
global___DMAttrBit = DMAttrBit

class _DmColorfulType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DmColorfulTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DmColorfulType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NoneType: _DmColorfulType.ValueType  # 0
    """无"""
    VipGradualColor: _DmColorfulType.ValueType  # 60001
    """渐变色"""

class DmColorfulType(_DmColorfulType, metaclass=_DmColorfulTypeEnumTypeWrapper): ...

NoneType: DmColorfulType.ValueType  # 0
"""无"""
VipGradualColor: DmColorfulType.ValueType  # 60001
"""渐变色"""
global___DmColorfulType = DmColorfulType

class _ExposureType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ExposureTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ExposureType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ExposureTypeNone: _ExposureType.ValueType  # 0
    """"""
    ExposureTypeDMSend: _ExposureType.ValueType  # 1
    """"""

class ExposureType(_ExposureType, metaclass=_ExposureTypeEnumTypeWrapper):
    """"""

ExposureTypeNone: ExposureType.ValueType  # 0
""""""
ExposureTypeDMSend: ExposureType.ValueType  # 1
""""""
global___ExposureType = ExposureType

class _PostPanelBizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PostPanelBizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PostPanelBizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PostPanelBizTypeNone: _PostPanelBizType.ValueType  # 0
    """"""
    PostPanelBizTypeEncourage: _PostPanelBizType.ValueType  # 1
    """"""
    PostPanelBizTypeColorDM: _PostPanelBizType.ValueType  # 2
    """"""
    PostPanelBizTypeNFTDM: _PostPanelBizType.ValueType  # 3
    """"""
    PostPanelBizTypeFragClose: _PostPanelBizType.ValueType  # 4
    """"""
    PostPanelBizTypeRecommend: _PostPanelBizType.ValueType  # 5
    """"""

class PostPanelBizType(_PostPanelBizType, metaclass=_PostPanelBizTypeEnumTypeWrapper):
    """"""

PostPanelBizTypeNone: PostPanelBizType.ValueType  # 0
""""""
PostPanelBizTypeEncourage: PostPanelBizType.ValueType  # 1
""""""
PostPanelBizTypeColorDM: PostPanelBizType.ValueType  # 2
""""""
PostPanelBizTypeNFTDM: PostPanelBizType.ValueType  # 3
""""""
PostPanelBizTypeFragClose: PostPanelBizType.ValueType  # 4
""""""
PostPanelBizTypeRecommend: PostPanelBizType.ValueType  # 5
""""""
global___PostPanelBizType = PostPanelBizType

class _PostStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _PostStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_PostStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PostStatusNormal: _PostStatus.ValueType  # 0
    """"""
    PostStatusClosed: _PostStatus.ValueType  # 1
    """"""

class PostStatus(_PostStatus, metaclass=_PostStatusEnumTypeWrapper):
    """"""

PostStatusNormal: PostStatus.ValueType  # 0
""""""
PostStatusClosed: PostStatus.ValueType  # 1
""""""
global___PostStatus = PostStatus

class _RenderType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RenderTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RenderType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RenderTypeNone: _RenderType.ValueType  # 0
    """"""
    RenderTypeSingle: _RenderType.ValueType  # 1
    """"""
    RenderTypeRotation: _RenderType.ValueType  # 2
    """"""

class RenderType(_RenderType, metaclass=_RenderTypeEnumTypeWrapper):
    """"""

RenderTypeNone: RenderType.ValueType  # 0
""""""
RenderTypeSingle: RenderType.ValueType  # 1
""""""
RenderTypeRotation: RenderType.ValueType  # 2
""""""
global___RenderType = RenderType

class _SubtitleAiStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SubtitleAiStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SubtitleAiStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Exposure: _SubtitleAiStatus.ValueType  # 1
    """"""
    Assist: _SubtitleAiStatus.ValueType  # 2
    """"""

class SubtitleAiStatus(_SubtitleAiStatus, metaclass=_SubtitleAiStatusEnumTypeWrapper):
    """"""

Exposure: SubtitleAiStatus.ValueType  # 1
""""""
Assist: SubtitleAiStatus.ValueType  # 2
""""""
global___SubtitleAiStatus = SubtitleAiStatus

class _SubtitleAiType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SubtitleAiTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SubtitleAiType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    Normal: _SubtitleAiType.ValueType  # 0
    """"""
    Translate: _SubtitleAiType.ValueType  # 1
    """"""

class SubtitleAiType(_SubtitleAiType, metaclass=_SubtitleAiTypeEnumTypeWrapper):
    """"""

Normal: SubtitleAiType.ValueType  # 0
""""""
Translate: SubtitleAiType.ValueType  # 1
""""""
global___SubtitleAiType = SubtitleAiType

class _SubtitleType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SubtitleTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SubtitleType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CC: _SubtitleType.ValueType  # 0
    """CC字幕"""
    AI: _SubtitleType.ValueType  # 1
    """AI生成字幕"""

class SubtitleType(_SubtitleType, metaclass=_SubtitleTypeEnumTypeWrapper): ...

CC: SubtitleType.ValueType  # 0
"""CC字幕"""
AI: SubtitleType.ValueType  # 1
"""AI生成字幕"""
global___SubtitleType = SubtitleType

class _ToastFunctionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ToastFunctionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ToastFunctionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ToastFunctionTypeNone: _ToastFunctionType.ValueType  # 0
    """"""
    ToastFunctionTypePostPanel: _ToastFunctionType.ValueType  # 1
    """"""

class ToastFunctionType(_ToastFunctionType, metaclass=_ToastFunctionTypeEnumTypeWrapper):
    """"""

ToastFunctionTypeNone: ToastFunctionType.ValueType  # 0
""""""
ToastFunctionTypePostPanel: ToastFunctionType.ValueType  # 1
""""""
global___ToastFunctionType = ToastFunctionType

@typing_extensions.final
class Avatar(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    AVATAR_TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """"""
    url: builtins.str
    """"""
    avatar_type: global___AvatarType.ValueType
    """"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        url: builtins.str = ...,
        avatar_type: global___AvatarType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar_type", b"avatar_type", "id", b"id", "url", b"url"]) -> None: ...

global___Avatar = Avatar

@typing_extensions.final
class Bubble(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["text", b"text", "url", b"url"]) -> None: ...

global___Bubble = Bubble

@typing_extensions.final
class BubbleV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    BUBBLE_TYPE_FIELD_NUMBER: builtins.int
    EXPOSURE_ONCE_FIELD_NUMBER: builtins.int
    EXPOSURE_TYPE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    url: builtins.str
    """"""
    bubble_type: global___BubbleType.ValueType
    """"""
    exposure_once: builtins.bool
    """"""
    exposure_type: global___ExposureType.ValueType
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        url: builtins.str = ...,
        bubble_type: global___BubbleType.ValueType = ...,
        exposure_once: builtins.bool = ...,
        exposure_type: global___ExposureType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble_type", b"bubble_type", "exposure_once", b"exposure_once", "exposure_type", b"exposure_type", "text", b"text", "url", b"url"]) -> None: ...

global___BubbleV2 = BubbleV2

@typing_extensions.final
class Button(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    action: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "text", b"text"]) -> None: ...

global___Button = Button

@typing_extensions.final
class BuzzwordConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORDS_FIELD_NUMBER: builtins.int
    @property
    def keywords(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___BuzzwordShowConfig]:
        """"""
    def __init__(
        self,
        *,
        keywords: collections.abc.Iterable[global___BuzzwordShowConfig] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keywords", b"keywords"]) -> None: ...

global___BuzzwordConfig = BuzzwordConfig

@typing_extensions.final
class BuzzwordShowConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    SCHEMA_FIELD_NUMBER: builtins.int
    SOURCE_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    BUZZWORD_ID_FIELD_NUMBER: builtins.int
    SCHEMA_TYPE_FIELD_NUMBER: builtins.int
    name: builtins.str
    """"""
    schema: builtins.str
    """"""
    source: builtins.int
    """"""
    id: builtins.int
    """"""
    buzzword_id: builtins.int
    """"""
    schema_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        schema: builtins.str = ...,
        source: builtins.int = ...,
        id: builtins.int = ...,
        buzzword_id: builtins.int = ...,
        schema_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["buzzword_id", b"buzzword_id", "id", b"id", "name", b"name", "schema", b"schema", "schema_type", b"schema_type", "source", b"source"]) -> None: ...

global___BuzzwordShowConfig = BuzzwordShowConfig

@typing_extensions.final
class CheckBox(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    type: global___CheckboxType.ValueType
    """"""
    default_value: builtins.bool
    """"""
    show: builtins.bool
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        type: global___CheckboxType.ValueType = ...,
        default_value: builtins.bool = ...,
        show: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "show", b"show", "text", b"text", "type", b"type"]) -> None: ...

global___CheckBox = CheckBox

@typing_extensions.final
class CheckBoxV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    DEFAULT_VALUE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    type: builtins.int
    """"""
    default_value: builtins.bool
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        type: builtins.int = ...,
        default_value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["default_value", b"default_value", "text", b"text", "type", b"type"]) -> None: ...

global___CheckBoxV2 = CheckBoxV2

@typing_extensions.final
class ClickButton(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORTRAIT_TEXT_FIELD_NUMBER: builtins.int
    LANDSCAPE_TEXT_FIELD_NUMBER: builtins.int
    PORTRAIT_TEXT_FOCUS_FIELD_NUMBER: builtins.int
    LANDSCAPE_TEXT_FOCUS_FIELD_NUMBER: builtins.int
    RENDER_TYPE_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    @property
    def portrait_text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def landscape_text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def portrait_text_focus(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def landscape_text_focus(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    render_type: global___RenderType.ValueType
    """"""
    show: builtins.bool
    """"""
    @property
    def bubble(self) -> global___Bubble:
        """"""
    def __init__(
        self,
        *,
        portrait_text: collections.abc.Iterable[builtins.str] | None = ...,
        landscape_text: collections.abc.Iterable[builtins.str] | None = ...,
        portrait_text_focus: collections.abc.Iterable[builtins.str] | None = ...,
        landscape_text_focus: collections.abc.Iterable[builtins.str] | None = ...,
        render_type: global___RenderType.ValueType = ...,
        show: builtins.bool = ...,
        bubble: global___Bubble | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bubble", b"bubble"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["bubble", b"bubble", "landscape_text", b"landscape_text", "landscape_text_focus", b"landscape_text_focus", "portrait_text", b"portrait_text", "portrait_text_focus", b"portrait_text_focus", "render_type", b"render_type", "show", b"show"]) -> None: ...

global___ClickButton = ClickButton

@typing_extensions.final
class ClickButtonV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORTRAIT_TEXT_FIELD_NUMBER: builtins.int
    LANDSCAPE_TEXT_FIELD_NUMBER: builtins.int
    PORTRAIT_TEXT_FOCUS_FIELD_NUMBER: builtins.int
    LANDSCAPE_TEXT_FOCUS_FIELD_NUMBER: builtins.int
    RENDER_TYPE_FIELD_NUMBER: builtins.int
    TEXT_INPUT_POST_FIELD_NUMBER: builtins.int
    EXPOSURE_ONCE_FIELD_NUMBER: builtins.int
    EXPOSURE_TYPE_FIELD_NUMBER: builtins.int
    @property
    def portrait_text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def landscape_text(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def portrait_text_focus(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def landscape_text_focus(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    render_type: builtins.int
    """"""
    text_input_post: builtins.bool
    """"""
    exposure_once: builtins.bool
    """"""
    exposure_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        portrait_text: collections.abc.Iterable[builtins.str] | None = ...,
        landscape_text: collections.abc.Iterable[builtins.str] | None = ...,
        portrait_text_focus: collections.abc.Iterable[builtins.str] | None = ...,
        landscape_text_focus: collections.abc.Iterable[builtins.str] | None = ...,
        render_type: builtins.int = ...,
        text_input_post: builtins.bool = ...,
        exposure_once: builtins.bool = ...,
        exposure_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["exposure_once", b"exposure_once", "exposure_type", b"exposure_type", "landscape_text", b"landscape_text", "landscape_text_focus", b"landscape_text_focus", "portrait_text", b"portrait_text", "portrait_text_focus", b"portrait_text_focus", "render_type", b"render_type", "text_input_post", b"text_input_post"]) -> None: ...

global___ClickButtonV2 = ClickButtonV2

@typing_extensions.final
class CommandDm(google.protobuf.message.Message):
    """互动弹幕条目信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    MID_FIELD_NUMBER: builtins.int
    COMMAND_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    MTIME_FIELD_NUMBER: builtins.int
    EXTRA_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕id"""
    oid: builtins.int
    """对象视频cid"""
    mid: builtins.str
    """发送者mid"""
    command: builtins.str
    """互动弹幕指令"""
    content: builtins.str
    """互动弹幕正文"""
    progress: builtins.int
    """出现时间"""
    ctime: builtins.str
    """创建时间"""
    mtime: builtins.str
    """发布时间"""
    extra: builtins.str
    """扩展json数据"""
    idStr: builtins.str
    """弹幕id str类型"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        oid: builtins.int = ...,
        mid: builtins.str = ...,
        command: builtins.str = ...,
        content: builtins.str = ...,
        progress: builtins.int = ...,
        ctime: builtins.str = ...,
        mtime: builtins.str = ...,
        extra: builtins.str = ...,
        idStr: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["command", b"command", "content", b"content", "ctime", b"ctime", "extra", b"extra", "id", b"id", "idStr", b"idStr", "mid", b"mid", "mtime", b"mtime", "oid", b"oid", "progress", b"progress"]) -> None: ...

global___CommandDm = CommandDm

@typing_extensions.final
class DanmakuAIFlag(google.protobuf.message.Message):
    """弹幕ai云屏蔽列表"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DM_FLAGS_FIELD_NUMBER: builtins.int
    @property
    def dm_flags(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuFlag]:
        """弹幕ai云屏蔽条目"""
    def __init__(
        self,
        *,
        dm_flags: collections.abc.Iterable[global___DanmakuFlag] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dm_flags", b"dm_flags"]) -> None: ...

global___DanmakuAIFlag = DanmakuAIFlag

@typing_extensions.final
class DanmakuElem(google.protobuf.message.Message):
    """弹幕条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    PROGRESS_FIELD_NUMBER: builtins.int
    MODE_FIELD_NUMBER: builtins.int
    FONTSIZE_FIELD_NUMBER: builtins.int
    COLOR_FIELD_NUMBER: builtins.int
    MIDHASH_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    CTIME_FIELD_NUMBER: builtins.int
    WEIGHT_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    IDSTR_FIELD_NUMBER: builtins.int
    ATTR_FIELD_NUMBER: builtins.int
    ANIMATION_FIELD_NUMBER: builtins.int
    COLORFUL_FIELD_NUMBER: builtins.int
    id: builtins.int
    """弹幕dmid"""
    progress: builtins.int
    """弹幕出现位置(单位ms)"""
    mode: builtins.int
    """弹幕类型 1 2 3:普通弹幕 4:底部弹幕 5:顶部弹幕 6:逆向弹幕 7:高级弹幕 8:代码弹幕 9:BAS弹幕(pool必须为2)"""
    fontsize: builtins.int
    """弹幕字号"""
    color: builtins.int
    """弹幕颜色"""
    midHash: builtins.str
    """发送者mid hash"""
    content: builtins.str
    """弹幕正文"""
    ctime: builtins.int
    """发送时间"""
    weight: builtins.int
    """权重 用于屏蔽等级 区间:[1,10]"""
    action: builtins.str
    """动作"""
    pool: builtins.int
    """弹幕池 0:普通池 1:字幕池 2:特殊池(代码/BAS弹幕)"""
    idStr: builtins.str
    """弹幕dmid str"""
    attr: builtins.int
    """弹幕属性位(bin求AND)
    bit0:保护 bit1:直播 bit2:高赞
    """
    animation: builtins.str
    """"""
    colorful: global___DmColorfulType.ValueType
    """大会员专属颜色"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        progress: builtins.int = ...,
        mode: builtins.int = ...,
        fontsize: builtins.int = ...,
        color: builtins.int = ...,
        midHash: builtins.str = ...,
        content: builtins.str = ...,
        ctime: builtins.int = ...,
        weight: builtins.int = ...,
        action: builtins.str = ...,
        pool: builtins.int = ...,
        idStr: builtins.str = ...,
        attr: builtins.int = ...,
        animation: builtins.str = ...,
        colorful: global___DmColorfulType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "animation", b"animation", "attr", b"attr", "color", b"color", "colorful", b"colorful", "content", b"content", "ctime", b"ctime", "fontsize", b"fontsize", "id", b"id", "idStr", b"idStr", "midHash", b"midHash", "mode", b"mode", "pool", b"pool", "progress", b"progress", "weight", b"weight"]) -> None: ...

global___DanmakuElem = DanmakuElem

@typing_extensions.final
class DanmakuFlag(google.protobuf.message.Message):
    """弹幕ai云屏蔽条目"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DMID_FIELD_NUMBER: builtins.int
    FLAG_FIELD_NUMBER: builtins.int
    dmid: builtins.int
    """弹幕dmid"""
    flag: builtins.int
    """评分"""
    def __init__(
        self,
        *,
        dmid: builtins.int = ...,
        flag: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dmid", b"dmid", "flag", b"flag"]) -> None: ...

global___DanmakuFlag = DanmakuFlag

@typing_extensions.final
class DanmakuFlagConfig(google.protobuf.message.Message):
    """云屏蔽配置信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REC_FLAG_FIELD_NUMBER: builtins.int
    REC_TEXT_FIELD_NUMBER: builtins.int
    REC_SWITCH_FIELD_NUMBER: builtins.int
    rec_flag: builtins.int
    """云屏蔽等级"""
    rec_text: builtins.str
    """云屏蔽文案"""
    rec_switch: builtins.int
    """云屏蔽开关"""
    def __init__(
        self,
        *,
        rec_flag: builtins.int = ...,
        rec_text: builtins.str = ...,
        rec_switch: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["rec_flag", b"rec_flag", "rec_switch", b"rec_switch", "rec_text", b"rec_text"]) -> None: ...

global___DanmakuFlagConfig = DanmakuFlagConfig

@typing_extensions.final
class DanmuDefaultPlayerConfig(google.protobuf.message.Message):
    """弹幕默认配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PlayerDanmakuAiRecommendedLevelV2MapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PLAYER_DANMAKU_USE_DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKTOP_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSCROLL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKCOLORFUL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKREPEAT_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_OPACITY_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SCALINGFACTOR_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SPEED_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SENIOR_MODE_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_V2_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_V2_MAP_FIELD_NUMBER: builtins.int
    player_danmaku_use_default_config: builtins.bool
    """是否使用推荐弹幕设置"""
    player_danmaku_ai_recommended_switch: builtins.bool
    """是否开启智能云屏蔽"""
    player_danmaku_ai_recommended_level: builtins.int
    """智能云屏蔽等级"""
    player_danmaku_blocktop: builtins.bool
    """是否屏蔽顶端弹幕"""
    player_danmaku_blockscroll: builtins.bool
    """是否屏蔽滚动弹幕"""
    player_danmaku_blockbottom: builtins.bool
    """是否屏蔽底端弹幕"""
    player_danmaku_blockcolorful: builtins.bool
    """是否屏蔽彩色弹幕"""
    player_danmaku_blockrepeat: builtins.bool
    """是否屏蔽重复弹幕"""
    player_danmaku_blockspecial: builtins.bool
    """是否屏蔽高级弹幕"""
    player_danmaku_opacity: builtins.float
    """弹幕不透明度"""
    player_danmaku_scalingfactor: builtins.float
    """弹幕缩放比例"""
    player_danmaku_domain: builtins.float
    """弹幕显示区域"""
    player_danmaku_speed: builtins.int
    """弹幕速度"""
    inline_player_danmaku_switch: builtins.bool
    """是否开启弹幕"""
    player_danmaku_senior_mode_switch: builtins.int
    """"""
    player_danmaku_ai_recommended_level_v2: builtins.int
    """"""
    @property
    def player_danmaku_ai_recommended_level_v2_map(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        player_danmaku_use_default_config: builtins.bool = ...,
        player_danmaku_ai_recommended_switch: builtins.bool = ...,
        player_danmaku_ai_recommended_level: builtins.int = ...,
        player_danmaku_blocktop: builtins.bool = ...,
        player_danmaku_blockscroll: builtins.bool = ...,
        player_danmaku_blockbottom: builtins.bool = ...,
        player_danmaku_blockcolorful: builtins.bool = ...,
        player_danmaku_blockrepeat: builtins.bool = ...,
        player_danmaku_blockspecial: builtins.bool = ...,
        player_danmaku_opacity: builtins.float = ...,
        player_danmaku_scalingfactor: builtins.float = ...,
        player_danmaku_domain: builtins.float = ...,
        player_danmaku_speed: builtins.int = ...,
        inline_player_danmaku_switch: builtins.bool = ...,
        player_danmaku_senior_mode_switch: builtins.int = ...,
        player_danmaku_ai_recommended_level_v2: builtins.int = ...,
        player_danmaku_ai_recommended_level_v2_map: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_player_danmaku_switch", b"inline_player_danmaku_switch", "player_danmaku_ai_recommended_level", b"player_danmaku_ai_recommended_level", "player_danmaku_ai_recommended_level_v2", b"player_danmaku_ai_recommended_level_v2", "player_danmaku_ai_recommended_level_v2_map", b"player_danmaku_ai_recommended_level_v2_map", "player_danmaku_ai_recommended_switch", b"player_danmaku_ai_recommended_switch", "player_danmaku_blockbottom", b"player_danmaku_blockbottom", "player_danmaku_blockcolorful", b"player_danmaku_blockcolorful", "player_danmaku_blockrepeat", b"player_danmaku_blockrepeat", "player_danmaku_blockscroll", b"player_danmaku_blockscroll", "player_danmaku_blockspecial", b"player_danmaku_blockspecial", "player_danmaku_blocktop", b"player_danmaku_blocktop", "player_danmaku_domain", b"player_danmaku_domain", "player_danmaku_opacity", b"player_danmaku_opacity", "player_danmaku_scalingfactor", b"player_danmaku_scalingfactor", "player_danmaku_senior_mode_switch", b"player_danmaku_senior_mode_switch", "player_danmaku_speed", b"player_danmaku_speed", "player_danmaku_use_default_config", b"player_danmaku_use_default_config"]) -> None: ...

global___DanmuDefaultPlayerConfig = DanmuDefaultPlayerConfig

@typing_extensions.final
class DanmuPlayerConfig(google.protobuf.message.Message):
    """弹幕配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class PlayerDanmakuAiRecommendedLevelV2MapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SWITCH_SAVE_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_USE_DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKTOP_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSCROLL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKCOLORFUL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKREPEAT_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_OPACITY_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SCALINGFACTOR_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SPEED_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_ENABLEBLOCKLIST_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_SWITCH_FIELD_NUMBER: builtins.int
    INLINE_PLAYER_DANMAKU_CONFIG_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_IOS_SWITCH_SAVE_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_SENIOR_MODE_SWITCH_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_V2_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_AI_RECOMMENDED_LEVEL_V2_MAP_FIELD_NUMBER: builtins.int
    player_danmaku_switch: builtins.bool
    """是否开启弹幕"""
    player_danmaku_switch_save: builtins.bool
    """是否记录弹幕开关设置"""
    player_danmaku_use_default_config: builtins.bool
    """是否使用推荐弹幕设置"""
    player_danmaku_ai_recommended_switch: builtins.bool
    """是否开启智能云屏蔽"""
    player_danmaku_ai_recommended_level: builtins.int
    """智能云屏蔽等级"""
    player_danmaku_blocktop: builtins.bool
    """是否屏蔽顶端弹幕"""
    player_danmaku_blockscroll: builtins.bool
    """是否屏蔽滚动弹幕"""
    player_danmaku_blockbottom: builtins.bool
    """是否屏蔽底端弹幕"""
    player_danmaku_blockcolorful: builtins.bool
    """是否屏蔽彩色弹幕"""
    player_danmaku_blockrepeat: builtins.bool
    """是否屏蔽重复弹幕"""
    player_danmaku_blockspecial: builtins.bool
    """是否屏蔽高级弹幕"""
    player_danmaku_opacity: builtins.float
    """弹幕不透明度"""
    player_danmaku_scalingfactor: builtins.float
    """弹幕缩放比例"""
    player_danmaku_domain: builtins.float
    """弹幕显示区域"""
    player_danmaku_speed: builtins.int
    """弹幕速度"""
    player_danmaku_enableblocklist: builtins.bool
    """是否开启屏蔽列表"""
    inline_player_danmaku_switch: builtins.bool
    """是否开启弹幕"""
    inline_player_danmaku_config: builtins.int
    """"""
    player_danmaku_ios_switch_save: builtins.int
    """"""
    player_danmaku_senior_mode_switch: builtins.int
    """"""
    player_danmaku_ai_recommended_level_v2: builtins.int
    """"""
    @property
    def player_danmaku_ai_recommended_level_v2_map(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        player_danmaku_switch: builtins.bool = ...,
        player_danmaku_switch_save: builtins.bool = ...,
        player_danmaku_use_default_config: builtins.bool = ...,
        player_danmaku_ai_recommended_switch: builtins.bool = ...,
        player_danmaku_ai_recommended_level: builtins.int = ...,
        player_danmaku_blocktop: builtins.bool = ...,
        player_danmaku_blockscroll: builtins.bool = ...,
        player_danmaku_blockbottom: builtins.bool = ...,
        player_danmaku_blockcolorful: builtins.bool = ...,
        player_danmaku_blockrepeat: builtins.bool = ...,
        player_danmaku_blockspecial: builtins.bool = ...,
        player_danmaku_opacity: builtins.float = ...,
        player_danmaku_scalingfactor: builtins.float = ...,
        player_danmaku_domain: builtins.float = ...,
        player_danmaku_speed: builtins.int = ...,
        player_danmaku_enableblocklist: builtins.bool = ...,
        inline_player_danmaku_switch: builtins.bool = ...,
        inline_player_danmaku_config: builtins.int = ...,
        player_danmaku_ios_switch_save: builtins.int = ...,
        player_danmaku_senior_mode_switch: builtins.int = ...,
        player_danmaku_ai_recommended_level_v2: builtins.int = ...,
        player_danmaku_ai_recommended_level_v2_map: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["inline_player_danmaku_config", b"inline_player_danmaku_config", "inline_player_danmaku_switch", b"inline_player_danmaku_switch", "player_danmaku_ai_recommended_level", b"player_danmaku_ai_recommended_level", "player_danmaku_ai_recommended_level_v2", b"player_danmaku_ai_recommended_level_v2", "player_danmaku_ai_recommended_level_v2_map", b"player_danmaku_ai_recommended_level_v2_map", "player_danmaku_ai_recommended_switch", b"player_danmaku_ai_recommended_switch", "player_danmaku_blockbottom", b"player_danmaku_blockbottom", "player_danmaku_blockcolorful", b"player_danmaku_blockcolorful", "player_danmaku_blockrepeat", b"player_danmaku_blockrepeat", "player_danmaku_blockscroll", b"player_danmaku_blockscroll", "player_danmaku_blockspecial", b"player_danmaku_blockspecial", "player_danmaku_blocktop", b"player_danmaku_blocktop", "player_danmaku_domain", b"player_danmaku_domain", "player_danmaku_enableblocklist", b"player_danmaku_enableblocklist", "player_danmaku_ios_switch_save", b"player_danmaku_ios_switch_save", "player_danmaku_opacity", b"player_danmaku_opacity", "player_danmaku_scalingfactor", b"player_danmaku_scalingfactor", "player_danmaku_senior_mode_switch", b"player_danmaku_senior_mode_switch", "player_danmaku_speed", b"player_danmaku_speed", "player_danmaku_switch", b"player_danmaku_switch", "player_danmaku_switch_save", b"player_danmaku_switch_save", "player_danmaku_use_default_config", b"player_danmaku_use_default_config"]) -> None: ...

global___DanmuPlayerConfig = DanmuPlayerConfig

@typing_extensions.final
class DanmuPlayerConfigPanel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SELECTION_TEXT_FIELD_NUMBER: builtins.int
    selection_text: builtins.str
    """"""
    def __init__(
        self,
        *,
        selection_text: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["selection_text", b"selection_text"]) -> None: ...

global___DanmuPlayerConfigPanel = DanmuPlayerConfigPanel

@typing_extensions.final
class DanmuPlayerDynamicConfig(google.protobuf.message.Message):
    """弹幕显示区域自动配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROGRESS_FIELD_NUMBER: builtins.int
    PLAYER_DANMAKU_DOMAIN_FIELD_NUMBER: builtins.int
    progress: builtins.int
    """时间"""
    player_danmaku_domain: builtins.float
    """弹幕显示区域"""
    def __init__(
        self,
        *,
        progress: builtins.int = ...,
        player_danmaku_domain: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["player_danmaku_domain", b"player_danmaku_domain", "progress", b"progress"]) -> None: ...

global___DanmuPlayerDynamicConfig = DanmuPlayerDynamicConfig

@typing_extensions.final
class DanmuPlayerViewConfig(google.protobuf.message.Message):
    """弹幕配置信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DANMUKU_DEFAULT_PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    DANMUKU_PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    DANMUKU_PLAYER_DYNAMIC_CONFIG_FIELD_NUMBER: builtins.int
    DANMUKU_PLAYER_CONFIG_PANEL_FIELD_NUMBER: builtins.int
    @property
    def danmuku_default_player_config(self) -> global___DanmuDefaultPlayerConfig:
        """弹幕默认配置"""
    @property
    def danmuku_player_config(self) -> global___DanmuPlayerConfig:
        """弹幕用户配置"""
    @property
    def danmuku_player_dynamic_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmuPlayerDynamicConfig]:
        """弹幕显示区域自动配置列表"""
    @property
    def danmuku_player_config_panel(self) -> global___DanmuPlayerConfigPanel:
        """"""
    def __init__(
        self,
        *,
        danmuku_default_player_config: global___DanmuDefaultPlayerConfig | None = ...,
        danmuku_player_config: global___DanmuPlayerConfig | None = ...,
        danmuku_player_dynamic_config: collections.abc.Iterable[global___DanmuPlayerDynamicConfig] | None = ...,
        danmuku_player_config_panel: global___DanmuPlayerConfigPanel | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["danmuku_default_player_config", b"danmuku_default_player_config", "danmuku_player_config", b"danmuku_player_config", "danmuku_player_config_panel", b"danmuku_player_config_panel"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["danmuku_default_player_config", b"danmuku_default_player_config", "danmuku_player_config", b"danmuku_player_config", "danmuku_player_config_panel", b"danmuku_player_config_panel", "danmuku_player_dynamic_config", b"danmuku_player_dynamic_config"]) -> None: ...

global___DanmuPlayerViewConfig = DanmuPlayerViewConfig

@typing_extensions.final
class DanmuWebPlayerConfig(google.protobuf.message.Message):
    """web端用户弹幕配置"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AiLevelV2MapEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.int
        value: builtins.int
        def __init__(
            self,
            *,
            key: builtins.int = ...,
            value: builtins.int = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    DM_SWITCH_FIELD_NUMBER: builtins.int
    AI_SWITCH_FIELD_NUMBER: builtins.int
    AI_LEVEL_FIELD_NUMBER: builtins.int
    BLOCKTOP_FIELD_NUMBER: builtins.int
    BLOCKSCROLL_FIELD_NUMBER: builtins.int
    BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    BLOCKCOLOR_FIELD_NUMBER: builtins.int
    BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    PREVENTSHADE_FIELD_NUMBER: builtins.int
    DMASK_FIELD_NUMBER: builtins.int
    OPACITY_FIELD_NUMBER: builtins.int
    DMAREA_FIELD_NUMBER: builtins.int
    SPEEDPLUS_FIELD_NUMBER: builtins.int
    FONTSIZE_FIELD_NUMBER: builtins.int
    SCREENSYNC_FIELD_NUMBER: builtins.int
    SPEEDSYNC_FIELD_NUMBER: builtins.int
    FONTFAMILY_FIELD_NUMBER: builtins.int
    BOLD_FIELD_NUMBER: builtins.int
    FONTBORDER_FIELD_NUMBER: builtins.int
    DRAW_TYPE_FIELD_NUMBER: builtins.int
    SENIOR_MODE_SWITCH_FIELD_NUMBER: builtins.int
    AI_LEVEL_V2_FIELD_NUMBER: builtins.int
    AI_LEVEL_V2_MAP_FIELD_NUMBER: builtins.int
    dm_switch: builtins.bool
    """是否开启弹幕"""
    ai_switch: builtins.bool
    """是否开启智能云屏蔽"""
    ai_level: builtins.int
    """智能云屏蔽等级"""
    blocktop: builtins.bool
    """是否屏蔽顶端弹幕"""
    blockscroll: builtins.bool
    """是否屏蔽滚动弹幕"""
    blockbottom: builtins.bool
    """是否屏蔽底端弹幕"""
    blockcolor: builtins.bool
    """是否屏蔽彩色弹幕"""
    blockspecial: builtins.bool
    """是否屏蔽重复弹幕"""
    preventshade: builtins.bool
    """"""
    dmask: builtins.bool
    """"""
    opacity: builtins.float
    """"""
    dmarea: builtins.int
    """"""
    speedplus: builtins.float
    """"""
    fontsize: builtins.float
    """弹幕字号"""
    screensync: builtins.bool
    """"""
    speedsync: builtins.bool
    """"""
    fontfamily: builtins.str
    """"""
    bold: builtins.bool
    """是否使用加粗"""
    fontborder: builtins.int
    """"""
    draw_type: builtins.str
    """弹幕渲染类型"""
    senior_mode_switch: builtins.int
    """"""
    ai_level_v2: builtins.int
    """"""
    @property
    def ai_level_v2_map(self) -> google.protobuf.internal.containers.ScalarMap[builtins.int, builtins.int]:
        """"""
    def __init__(
        self,
        *,
        dm_switch: builtins.bool = ...,
        ai_switch: builtins.bool = ...,
        ai_level: builtins.int = ...,
        blocktop: builtins.bool = ...,
        blockscroll: builtins.bool = ...,
        blockbottom: builtins.bool = ...,
        blockcolor: builtins.bool = ...,
        blockspecial: builtins.bool = ...,
        preventshade: builtins.bool = ...,
        dmask: builtins.bool = ...,
        opacity: builtins.float = ...,
        dmarea: builtins.int = ...,
        speedplus: builtins.float = ...,
        fontsize: builtins.float = ...,
        screensync: builtins.bool = ...,
        speedsync: builtins.bool = ...,
        fontfamily: builtins.str = ...,
        bold: builtins.bool = ...,
        fontborder: builtins.int = ...,
        draw_type: builtins.str = ...,
        senior_mode_switch: builtins.int = ...,
        ai_level_v2: builtins.int = ...,
        ai_level_v2_map: collections.abc.Mapping[builtins.int, builtins.int] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_level", b"ai_level", "ai_level_v2", b"ai_level_v2", "ai_level_v2_map", b"ai_level_v2_map", "ai_switch", b"ai_switch", "blockbottom", b"blockbottom", "blockcolor", b"blockcolor", "blockscroll", b"blockscroll", "blockspecial", b"blockspecial", "blocktop", b"blocktop", "bold", b"bold", "dm_switch", b"dm_switch", "dmarea", b"dmarea", "dmask", b"dmask", "draw_type", b"draw_type", "fontborder", b"fontborder", "fontfamily", b"fontfamily", "fontsize", b"fontsize", "opacity", b"opacity", "preventshade", b"preventshade", "screensync", b"screensync", "senior_mode_switch", b"senior_mode_switch", "speedplus", b"speedplus", "speedsync", b"speedsync"]) -> None: ...

global___DanmuWebPlayerConfig = DanmuWebPlayerConfig

@typing_extensions.final
class DmColorful(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    SRC_FIELD_NUMBER: builtins.int
    type: global___DmColorfulType.ValueType
    """颜色类型"""
    src: builtins.str
    """"""
    def __init__(
        self,
        *,
        type: global___DmColorfulType.ValueType = ...,
        src: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["src", b"src", "type", b"type"]) -> None: ...

global___DmColorful = DmColorful

@typing_extensions.final
class DmExpoReportReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SESSION_ID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    session_id: builtins.str
    """"""
    oid: builtins.int
    """"""
    spmid: builtins.str
    """"""
    def __init__(
        self,
        *,
        session_id: builtins.str = ...,
        oid: builtins.int = ...,
        spmid: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "session_id", b"session_id", "spmid", b"spmid"]) -> None: ...

global___DmExpoReportReq = DmExpoReportReq

@typing_extensions.final
class DmExpoReportRes(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DmExpoReportRes = DmExpoReportRes

@typing_extensions.final
class DmPlayerConfigReq(google.protobuf.message.Message):
    """修改弹幕配置-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TS_FIELD_NUMBER: builtins.int
    SWITCH_FIELD_NUMBER: builtins.int
    SWITCH_SAVE_FIELD_NUMBER: builtins.int
    USE_DEFAULT_CONFIG_FIELD_NUMBER: builtins.int
    AI_RECOMMENDED_SWITCH_FIELD_NUMBER: builtins.int
    AI_RECOMMENDED_LEVEL_FIELD_NUMBER: builtins.int
    BLOCKTOP_FIELD_NUMBER: builtins.int
    BLOCKSCROLL_FIELD_NUMBER: builtins.int
    BLOCKBOTTOM_FIELD_NUMBER: builtins.int
    BLOCKCOLORFUL_FIELD_NUMBER: builtins.int
    BLOCKREPEAT_FIELD_NUMBER: builtins.int
    BLOCKSPECIAL_FIELD_NUMBER: builtins.int
    OPACITY_FIELD_NUMBER: builtins.int
    SCALINGFACTOR_FIELD_NUMBER: builtins.int
    DOMAIN_FIELD_NUMBER: builtins.int
    SPEED_FIELD_NUMBER: builtins.int
    ENABLEBLOCKLIST_FIELD_NUMBER: builtins.int
    INLINEPLAYERDANMAKUSWITCH_FIELD_NUMBER: builtins.int
    SENIOR_MODE_SWITCH_FIELD_NUMBER: builtins.int
    AI_RECOMMENDED_LEVEL_V2_FIELD_NUMBER: builtins.int
    ts: builtins.int
    """"""
    @property
    def switch(self) -> global___PlayerDanmakuSwitch:
        """是否开启弹幕"""
    @property
    def switch_save(self) -> global___PlayerDanmakuSwitchSave:
        """是否记录弹幕开关设置"""
    @property
    def use_default_config(self) -> global___PlayerDanmakuUseDefaultConfig:
        """是否使用推荐弹幕设置"""
    @property
    def ai_recommended_switch(self) -> global___PlayerDanmakuAiRecommendedSwitch:
        """是否开启智能云屏蔽"""
    @property
    def ai_recommended_level(self) -> global___PlayerDanmakuAiRecommendedLevel:
        """智能云屏蔽等级"""
    @property
    def blocktop(self) -> global___PlayerDanmakuBlocktop:
        """是否屏蔽顶端弹幕"""
    @property
    def blockscroll(self) -> global___PlayerDanmakuBlockscroll:
        """是否屏蔽滚动弹幕"""
    @property
    def blockbottom(self) -> global___PlayerDanmakuBlockbottom:
        """是否屏蔽底端弹幕"""
    @property
    def blockcolorful(self) -> global___PlayerDanmakuBlockcolorful:
        """是否屏蔽彩色弹幕"""
    @property
    def blockrepeat(self) -> global___PlayerDanmakuBlockrepeat:
        """是否屏蔽重复弹幕"""
    @property
    def blockspecial(self) -> global___PlayerDanmakuBlockspecial:
        """是否屏蔽高级弹幕"""
    @property
    def opacity(self) -> global___PlayerDanmakuOpacity:
        """弹幕不透明度"""
    @property
    def scalingfactor(self) -> global___PlayerDanmakuScalingfactor:
        """弹幕缩放比例"""
    @property
    def domain(self) -> global___PlayerDanmakuDomain:
        """弹幕显示区域"""
    @property
    def speed(self) -> global___PlayerDanmakuSpeed:
        """弹幕速度"""
    @property
    def enableblocklist(self) -> global___PlayerDanmakuEnableblocklist:
        """是否开启屏蔽列表"""
    @property
    def inlinePlayerDanmakuSwitch(self) -> global___InlinePlayerDanmakuSwitch:
        """是否开启弹幕"""
    @property
    def senior_mode_switch(self) -> global___PlayerDanmakuSeniorModeSwitch:
        """"""
    @property
    def ai_recommended_level_v2(self) -> global___PlayerDanmakuAiRecommendedLevelV2:
        """"""
    def __init__(
        self,
        *,
        ts: builtins.int = ...,
        switch: global___PlayerDanmakuSwitch | None = ...,
        switch_save: global___PlayerDanmakuSwitchSave | None = ...,
        use_default_config: global___PlayerDanmakuUseDefaultConfig | None = ...,
        ai_recommended_switch: global___PlayerDanmakuAiRecommendedSwitch | None = ...,
        ai_recommended_level: global___PlayerDanmakuAiRecommendedLevel | None = ...,
        blocktop: global___PlayerDanmakuBlocktop | None = ...,
        blockscroll: global___PlayerDanmakuBlockscroll | None = ...,
        blockbottom: global___PlayerDanmakuBlockbottom | None = ...,
        blockcolorful: global___PlayerDanmakuBlockcolorful | None = ...,
        blockrepeat: global___PlayerDanmakuBlockrepeat | None = ...,
        blockspecial: global___PlayerDanmakuBlockspecial | None = ...,
        opacity: global___PlayerDanmakuOpacity | None = ...,
        scalingfactor: global___PlayerDanmakuScalingfactor | None = ...,
        domain: global___PlayerDanmakuDomain | None = ...,
        speed: global___PlayerDanmakuSpeed | None = ...,
        enableblocklist: global___PlayerDanmakuEnableblocklist | None = ...,
        inlinePlayerDanmakuSwitch: global___InlinePlayerDanmakuSwitch | None = ...,
        senior_mode_switch: global___PlayerDanmakuSeniorModeSwitch | None = ...,
        ai_recommended_level_v2: global___PlayerDanmakuAiRecommendedLevelV2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_recommended_level", b"ai_recommended_level", "ai_recommended_level_v2", b"ai_recommended_level_v2", "ai_recommended_switch", b"ai_recommended_switch", "blockbottom", b"blockbottom", "blockcolorful", b"blockcolorful", "blockrepeat", b"blockrepeat", "blockscroll", b"blockscroll", "blockspecial", b"blockspecial", "blocktop", b"blocktop", "domain", b"domain", "enableblocklist", b"enableblocklist", "inlinePlayerDanmakuSwitch", b"inlinePlayerDanmakuSwitch", "opacity", b"opacity", "scalingfactor", b"scalingfactor", "senior_mode_switch", b"senior_mode_switch", "speed", b"speed", "switch", b"switch", "switch_save", b"switch_save", "use_default_config", b"use_default_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_recommended_level", b"ai_recommended_level", "ai_recommended_level_v2", b"ai_recommended_level_v2", "ai_recommended_switch", b"ai_recommended_switch", "blockbottom", b"blockbottom", "blockcolorful", b"blockcolorful", "blockrepeat", b"blockrepeat", "blockscroll", b"blockscroll", "blockspecial", b"blockspecial", "blocktop", b"blocktop", "domain", b"domain", "enableblocklist", b"enableblocklist", "inlinePlayerDanmakuSwitch", b"inlinePlayerDanmakuSwitch", "opacity", b"opacity", "scalingfactor", b"scalingfactor", "senior_mode_switch", b"senior_mode_switch", "speed", b"speed", "switch", b"switch", "switch_save", b"switch_save", "ts", b"ts", "use_default_config", b"use_default_config"]) -> None: ...

global___DmPlayerConfigReq = DmPlayerConfigReq

@typing_extensions.final
class DmSegConfig(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PAGE_SIZE_FIELD_NUMBER: builtins.int
    TOTAL_FIELD_NUMBER: builtins.int
    page_size: builtins.int
    """"""
    total: builtins.int
    """"""
    def __init__(
        self,
        *,
        page_size: builtins.int = ...,
        total: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["page_size", b"page_size", "total", b"total"]) -> None: ...

global___DmSegConfig = DmSegConfig

@typing_extensions.final
class DmSegMobileReply(google.protobuf.message.Message):
    """获取弹幕-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELEMS_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    AI_FLAG_FIELD_NUMBER: builtins.int
    COLORFULSRC_FIELD_NUMBER: builtins.int
    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuElem]:
        """弹幕列表"""
    state: builtins.int
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """
    @property
    def ai_flag(self) -> global___DanmakuAIFlag:
        """弹幕云屏蔽ai评分值"""
    @property
    def colorfulSrc(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DmColorful]: ...
    def __init__(
        self,
        *,
        elems: collections.abc.Iterable[global___DanmakuElem] | None = ...,
        state: builtins.int = ...,
        ai_flag: global___DanmakuAIFlag | None = ...,
        colorfulSrc: collections.abc.Iterable[global___DmColorful] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_flag", b"ai_flag"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_flag", b"ai_flag", "colorfulSrc", b"colorfulSrc", "elems", b"elems", "state", b"state"]) -> None: ...

global___DmSegMobileReply = DmSegMobileReply

@typing_extensions.final
class DmSegMobileReq(google.protobuf.message.Message):
    """获取弹幕-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SEGMENT_INDEX_FIELD_NUMBER: builtins.int
    TEENAGERS_MODE_FIELD_NUMBER: builtins.int
    PS_FIELD_NUMBER: builtins.int
    PE_FIELD_NUMBER: builtins.int
    PULL_MODE_FIELD_NUMBER: builtins.int
    FROM_SCENE_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""
    oid: builtins.int
    """视频cid/漫画cid"""
    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """
    segment_index: builtins.int
    """分段(6min)"""
    teenagers_mode: builtins.int
    """是否青少年模式"""
    ps: builtins.int
    """"""
    pe: builtins.int
    """"""
    pull_mode: builtins.int
    """"""
    from_scene: builtins.int
    """"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        segment_index: builtins.int = ...,
        teenagers_mode: builtins.int = ...,
        ps: builtins.int = ...,
        pe: builtins.int = ...,
        pull_mode: builtins.int = ...,
        from_scene: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["from_scene", b"from_scene", "oid", b"oid", "pe", b"pe", "pid", b"pid", "ps", b"ps", "pull_mode", b"pull_mode", "segment_index", b"segment_index", "teenagers_mode", b"teenagers_mode", "type", b"type"]) -> None: ...

global___DmSegMobileReq = DmSegMobileReq

@typing_extensions.final
class DmSegOttReply(google.protobuf.message.Message):
    """ott弹幕列表-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOSED_FIELD_NUMBER: builtins.int
    ELEMS_FIELD_NUMBER: builtins.int
    closed: builtins.bool
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """
    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuElem]:
        """弹幕列表"""
    def __init__(
        self,
        *,
        closed: builtins.bool = ...,
        elems: collections.abc.Iterable[global___DanmakuElem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["closed", b"closed", "elems", b"elems"]) -> None: ...

global___DmSegOttReply = DmSegOttReply

@typing_extensions.final
class DmSegOttReq(google.protobuf.message.Message):
    """ott弹幕列表-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SEGMENT_INDEX_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""
    oid: builtins.int
    """视频cid/漫画cid"""
    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """
    segment_index: builtins.int
    """分段(6min)"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        segment_index: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "pid", b"pid", "segment_index", b"segment_index", "type", b"type"]) -> None: ...

global___DmSegOttReq = DmSegOttReq

@typing_extensions.final
class DmSegSDKReply(google.protobuf.message.Message):
    """弹幕SDK-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOSED_FIELD_NUMBER: builtins.int
    ELEMS_FIELD_NUMBER: builtins.int
    closed: builtins.bool
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """
    @property
    def elems(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DanmakuElem]:
        """弹幕列表"""
    def __init__(
        self,
        *,
        closed: builtins.bool = ...,
        elems: collections.abc.Iterable[global___DanmakuElem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["closed", b"closed", "elems", b"elems"]) -> None: ...

global___DmSegSDKReply = DmSegSDKReply

@typing_extensions.final
class DmSegSDKReq(google.protobuf.message.Message):
    """弹幕SDK-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SEGMENT_INDEX_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""
    oid: builtins.int
    """视频cid/漫画cid"""
    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """
    segment_index: builtins.int
    """分段(6min)"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        segment_index: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["oid", b"oid", "pid", b"pid", "segment_index", b"segment_index", "type", b"type"]) -> None: ...

global___DmSegSDKReq = DmSegSDKReq

@typing_extensions.final
class DmViewReply(google.protobuf.message.Message):
    """客户端弹幕元数据-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLOSED_FIELD_NUMBER: builtins.int
    MASK_FIELD_NUMBER: builtins.int
    SUBTITLE_FIELD_NUMBER: builtins.int
    SPECIAL_DMS_FIELD_NUMBER: builtins.int
    AI_FLAG_FIELD_NUMBER: builtins.int
    PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    SEND_BOX_STYLE_FIELD_NUMBER: builtins.int
    ALLOW_FIELD_NUMBER: builtins.int
    CHECK_BOX_FIELD_NUMBER: builtins.int
    CHECK_BOX_SHOW_MSG_FIELD_NUMBER: builtins.int
    TEXT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    INPUT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    REPORT_FILTER_CONTENT_FIELD_NUMBER: builtins.int
    EXPO_REPORT_FIELD_NUMBER: builtins.int
    BUZZWORD_CONFIG_FIELD_NUMBER: builtins.int
    EXPRESSIONS_FIELD_NUMBER: builtins.int
    POST_PANEL_FIELD_NUMBER: builtins.int
    ACTIVITY_META_FIELD_NUMBER: builtins.int
    POST_PANEL2_FIELD_NUMBER: builtins.int
    closed: builtins.bool
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """
    @property
    def mask(self) -> global___VideoMask:
        """智能防挡弹幕蒙版信息"""
    @property
    def subtitle(self) -> global___VideoSubtitle:
        """视频字幕"""
    @property
    def special_dms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """高级弹幕专包url(bfs)"""
    @property
    def ai_flag(self) -> global___DanmakuFlagConfig:
        """云屏蔽配置信息"""
    @property
    def player_config(self) -> global___DanmuPlayerViewConfig:
        """弹幕配置信息"""
    send_box_style: builtins.int
    """弹幕发送框样式"""
    allow: builtins.bool
    """是否允许"""
    check_box: builtins.str
    """check box 是否展示"""
    check_box_show_msg: builtins.str
    """check box 展示文本"""
    text_placeholder: builtins.str
    """展示文案"""
    input_placeholder: builtins.str
    """弹幕输入框文案"""
    @property
    def report_filter_content(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """用户举报弹幕 cid维度屏蔽的正则规则"""
    @property
    def expo_report(self) -> global___ExpoReport:
        """"""
    @property
    def buzzword_config(self) -> global___BuzzwordConfig:
        """"""
    @property
    def expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Expressions]:
        """"""
    @property
    def post_panel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PostPanel]:
        """"""
    @property
    def activity_meta(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def post_panel2(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PostPanelV2]:
        """"""
    def __init__(
        self,
        *,
        closed: builtins.bool = ...,
        mask: global___VideoMask | None = ...,
        subtitle: global___VideoSubtitle | None = ...,
        special_dms: collections.abc.Iterable[builtins.str] | None = ...,
        ai_flag: global___DanmakuFlagConfig | None = ...,
        player_config: global___DanmuPlayerViewConfig | None = ...,
        send_box_style: builtins.int = ...,
        allow: builtins.bool = ...,
        check_box: builtins.str = ...,
        check_box_show_msg: builtins.str = ...,
        text_placeholder: builtins.str = ...,
        input_placeholder: builtins.str = ...,
        report_filter_content: collections.abc.Iterable[builtins.str] | None = ...,
        expo_report: global___ExpoReport | None = ...,
        buzzword_config: global___BuzzwordConfig | None = ...,
        expressions: collections.abc.Iterable[global___Expressions] | None = ...,
        post_panel: collections.abc.Iterable[global___PostPanel] | None = ...,
        activity_meta: collections.abc.Iterable[builtins.str] | None = ...,
        post_panel2: collections.abc.Iterable[global___PostPanelV2] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ai_flag", b"ai_flag", "buzzword_config", b"buzzword_config", "expo_report", b"expo_report", "mask", b"mask", "player_config", b"player_config", "subtitle", b"subtitle"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_meta", b"activity_meta", "ai_flag", b"ai_flag", "allow", b"allow", "buzzword_config", b"buzzword_config", "check_box", b"check_box", "check_box_show_msg", b"check_box_show_msg", "closed", b"closed", "expo_report", b"expo_report", "expressions", b"expressions", "input_placeholder", b"input_placeholder", "mask", b"mask", "player_config", b"player_config", "post_panel", b"post_panel", "post_panel2", b"post_panel2", "report_filter_content", b"report_filter_content", "send_box_style", b"send_box_style", "special_dms", b"special_dms", "subtitle", b"subtitle", "text_placeholder", b"text_placeholder"]) -> None: ...

global___DmViewReply = DmViewReply

@typing_extensions.final
class DmViewReq(google.protobuf.message.Message):
    """客户端弹幕元数据-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PID_FIELD_NUMBER: builtins.int
    OID_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    IS_HARD_BOOT_FIELD_NUMBER: builtins.int
    pid: builtins.int
    """稿件avid/漫画epid"""
    oid: builtins.int
    """视频cid/漫画cid"""
    type: builtins.int
    """弹幕类型
    1:视频 2:漫画
    """
    spmid: builtins.str
    """页面spm"""
    is_hard_boot: builtins.int
    """是否冷启"""
    def __init__(
        self,
        *,
        pid: builtins.int = ...,
        oid: builtins.int = ...,
        type: builtins.int = ...,
        spmid: builtins.str = ...,
        is_hard_boot: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_hard_boot", b"is_hard_boot", "oid", b"oid", "pid", b"pid", "spmid", b"spmid", "type", b"type"]) -> None: ...

global___DmViewReq = DmViewReq

@typing_extensions.final
class DmWebViewReply(google.protobuf.message.Message):
    """web端弹幕元数据-响应
    https://api.bilibili.com/x/v2/dm/web/view
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATE_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    TEXT_SIDE_FIELD_NUMBER: builtins.int
    DM_SGE_FIELD_NUMBER: builtins.int
    FLAG_FIELD_NUMBER: builtins.int
    SPECIAL_DMS_FIELD_NUMBER: builtins.int
    CHECK_BOX_FIELD_NUMBER: builtins.int
    COUNT_FIELD_NUMBER: builtins.int
    COMMANDDMS_FIELD_NUMBER: builtins.int
    PLAYER_CONFIG_FIELD_NUMBER: builtins.int
    REPORT_FILTER_CONTENT_FIELD_NUMBER: builtins.int
    EXPRESSIONS_FIELD_NUMBER: builtins.int
    POST_PANEL_FIELD_NUMBER: builtins.int
    ACTIVITY_META_FIELD_NUMBER: builtins.int
    state: builtins.int
    """是否已关闭弹幕
    0:未关闭 1:已关闭
    """
    text: builtins.str
    """"""
    text_side: builtins.str
    """"""
    @property
    def dm_sge(self) -> global___DmSegConfig:
        """分段弹幕配置"""
    @property
    def flag(self) -> global___DanmakuFlagConfig:
        """云屏蔽配置信息"""
    @property
    def special_dms(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """高级弹幕专包url(bfs)"""
    check_box: builtins.bool
    """check box 是否展示"""
    count: builtins.int
    """弹幕数"""
    @property
    def commandDms(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CommandDm]:
        """互动弹幕"""
    @property
    def player_config(self) -> global___DanmuWebPlayerConfig:
        """用户弹幕配置"""
    @property
    def report_filter_content(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """用户举报弹幕 cid维度屏蔽"""
    @property
    def expressions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Expressions]:
        """"""
    @property
    def post_panel(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PostPanel]:
        """"""
    @property
    def activity_meta(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    def __init__(
        self,
        *,
        state: builtins.int = ...,
        text: builtins.str = ...,
        text_side: builtins.str = ...,
        dm_sge: global___DmSegConfig | None = ...,
        flag: global___DanmakuFlagConfig | None = ...,
        special_dms: collections.abc.Iterable[builtins.str] | None = ...,
        check_box: builtins.bool = ...,
        count: builtins.int = ...,
        commandDms: collections.abc.Iterable[global___CommandDm] | None = ...,
        player_config: global___DanmuWebPlayerConfig | None = ...,
        report_filter_content: collections.abc.Iterable[builtins.str] | None = ...,
        expressions: collections.abc.Iterable[global___Expressions] | None = ...,
        post_panel: collections.abc.Iterable[global___PostPanel] | None = ...,
        activity_meta: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dm_sge", b"dm_sge", "flag", b"flag", "player_config", b"player_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_meta", b"activity_meta", "check_box", b"check_box", "commandDms", b"commandDms", "count", b"count", "dm_sge", b"dm_sge", "expressions", b"expressions", "flag", b"flag", "player_config", b"player_config", "post_panel", b"post_panel", "report_filter_content", b"report_filter_content", "special_dms", b"special_dms", "state", b"state", "text", b"text", "text_side", b"text_side"]) -> None: ...

global___DmWebViewReply = DmWebViewReply

@typing_extensions.final
class ExpoReport(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SHOULD_REPORT_AT_END_FIELD_NUMBER: builtins.int
    should_report_at_end: builtins.bool
    """"""
    def __init__(
        self,
        *,
        should_report_at_end: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["should_report_at_end", b"should_report_at_end"]) -> None: ...

global___ExpoReport = ExpoReport

@typing_extensions.final
class Expression(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEYWORD_FIELD_NUMBER: builtins.int
    URL_FIELD_NUMBER: builtins.int
    PERIOD_FIELD_NUMBER: builtins.int
    @property
    def keyword(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    url: builtins.str
    """"""
    @property
    def period(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Period]:
        """"""
    def __init__(
        self,
        *,
        keyword: collections.abc.Iterable[builtins.str] | None = ...,
        url: builtins.str = ...,
        period: collections.abc.Iterable[global___Period] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["keyword", b"keyword", "period", b"period", "url", b"url"]) -> None: ...

global___Expression = Expression

@typing_extensions.final
class Expressions(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DATA_FIELD_NUMBER: builtins.int
    @property
    def data(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Expression]:
        """"""
    def __init__(
        self,
        *,
        data: collections.abc.Iterable[global___Expression] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data"]) -> None: ...

global___Expressions = Expressions

@typing_extensions.final
class InlinePlayerDanmakuSwitch(google.protobuf.message.Message):
    """是否开启弹幕"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    """"""
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___InlinePlayerDanmakuSwitch = InlinePlayerDanmakuSwitch

@typing_extensions.final
class Label(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def content(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        content: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "title", b"title"]) -> None: ...

global___Label = Label

@typing_extensions.final
class LabelV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TITLE_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    EXPOSURE_ONCE_FIELD_NUMBER: builtins.int
    EXPOSURE_TYPE_FIELD_NUMBER: builtins.int
    title: builtins.str
    """"""
    @property
    def content(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    exposure_once: builtins.bool
    """"""
    exposure_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        title: builtins.str = ...,
        content: collections.abc.Iterable[builtins.str] | None = ...,
        exposure_once: builtins.bool = ...,
        exposure_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "exposure_once", b"exposure_once", "exposure_type", b"exposure_type", "title", b"title"]) -> None: ...

global___LabelV2 = LabelV2

@typing_extensions.final
class Period(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    start: builtins.int
    """"""
    end: builtins.int
    """"""
    def __init__(
        self,
        *,
        start: builtins.int = ...,
        end: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["end", b"end", "start", b"start"]) -> None: ...

global___Period = Period

@typing_extensions.final
class PlayerDanmakuAiRecommendedLevel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuAiRecommendedLevel = PlayerDanmakuAiRecommendedLevel

@typing_extensions.final
class PlayerDanmakuAiRecommendedLevelV2(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuAiRecommendedLevelV2 = PlayerDanmakuAiRecommendedLevelV2

@typing_extensions.final
class PlayerDanmakuAiRecommendedSwitch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuAiRecommendedSwitch = PlayerDanmakuAiRecommendedSwitch

@typing_extensions.final
class PlayerDanmakuBlockbottom(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuBlockbottom = PlayerDanmakuBlockbottom

@typing_extensions.final
class PlayerDanmakuBlockcolorful(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuBlockcolorful = PlayerDanmakuBlockcolorful

@typing_extensions.final
class PlayerDanmakuBlockrepeat(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuBlockrepeat = PlayerDanmakuBlockrepeat

@typing_extensions.final
class PlayerDanmakuBlockscroll(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuBlockscroll = PlayerDanmakuBlockscroll

@typing_extensions.final
class PlayerDanmakuBlockspecial(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuBlockspecial = PlayerDanmakuBlockspecial

@typing_extensions.final
class PlayerDanmakuBlocktop(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuBlocktop = PlayerDanmakuBlocktop

@typing_extensions.final
class PlayerDanmakuDomain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuDomain = PlayerDanmakuDomain

@typing_extensions.final
class PlayerDanmakuEnableblocklist(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuEnableblocklist = PlayerDanmakuEnableblocklist

@typing_extensions.final
class PlayerDanmakuOpacity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuOpacity = PlayerDanmakuOpacity

@typing_extensions.final
class PlayerDanmakuScalingfactor(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.float
    def __init__(
        self,
        *,
        value: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuScalingfactor = PlayerDanmakuScalingfactor

@typing_extensions.final
class PlayerDanmakuSeniorModeSwitch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuSeniorModeSwitch = PlayerDanmakuSeniorModeSwitch

@typing_extensions.final
class PlayerDanmakuSpeed(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.int
    def __init__(
        self,
        *,
        value: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuSpeed = PlayerDanmakuSpeed

@typing_extensions.final
class PlayerDanmakuSwitch(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    CAN_IGNORE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    can_ignore: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
        can_ignore: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["can_ignore", b"can_ignore", "value", b"value"]) -> None: ...

global___PlayerDanmakuSwitch = PlayerDanmakuSwitch

@typing_extensions.final
class PlayerDanmakuSwitchSave(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuSwitchSave = PlayerDanmakuSwitchSave

@typing_extensions.final
class PlayerDanmakuUseDefaultConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    value: builtins.bool
    def __init__(
        self,
        *,
        value: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["value", b"value"]) -> None: ...

global___PlayerDanmakuUseDefaultConfig = PlayerDanmakuUseDefaultConfig

@typing_extensions.final
class PostPanel(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    PRIORITY_FIELD_NUMBER: builtins.int
    BIZ_ID_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    CLICK_BUTTON_FIELD_NUMBER: builtins.int
    TEXT_INPUT_FIELD_NUMBER: builtins.int
    CHECK_BOX_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    start: builtins.int
    """"""
    end: builtins.int
    """"""
    priority: builtins.int
    """"""
    biz_id: builtins.int
    """"""
    biz_type: global___PostPanelBizType.ValueType
    """"""
    @property
    def click_button(self) -> global___ClickButton:
        """"""
    @property
    def text_input(self) -> global___TextInput:
        """"""
    @property
    def check_box(self) -> global___CheckBox:
        """"""
    @property
    def toast(self) -> global___Toast:
        """"""
    def __init__(
        self,
        *,
        start: builtins.int = ...,
        end: builtins.int = ...,
        priority: builtins.int = ...,
        biz_id: builtins.int = ...,
        biz_type: global___PostPanelBizType.ValueType = ...,
        click_button: global___ClickButton | None = ...,
        text_input: global___TextInput | None = ...,
        check_box: global___CheckBox | None = ...,
        toast: global___Toast | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["check_box", b"check_box", "click_button", b"click_button", "text_input", b"text_input", "toast", b"toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_id", b"biz_id", "biz_type", b"biz_type", "check_box", b"check_box", "click_button", b"click_button", "end", b"end", "priority", b"priority", "start", b"start", "text_input", b"text_input", "toast", b"toast"]) -> None: ...

global___PostPanel = PostPanel

@typing_extensions.final
class PostPanelV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    START_FIELD_NUMBER: builtins.int
    END_FIELD_NUMBER: builtins.int
    BIZ_TYPE_FIELD_NUMBER: builtins.int
    CLICK_BUTTON_FIELD_NUMBER: builtins.int
    TEXT_INPUT_FIELD_NUMBER: builtins.int
    CHECK_BOX_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    BUBBLE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    POST_STATUS_FIELD_NUMBER: builtins.int
    start: builtins.int
    """"""
    end: builtins.int
    """"""
    biz_type: builtins.int
    """"""
    @property
    def click_button(self) -> global___ClickButtonV2:
        """"""
    @property
    def text_input(self) -> global___TextInputV2:
        """"""
    @property
    def check_box(self) -> global___CheckBoxV2:
        """"""
    @property
    def toast(self) -> global___ToastV2:
        """"""
    @property
    def bubble(self) -> global___BubbleV2:
        """"""
    @property
    def label(self) -> global___LabelV2:
        """"""
    post_status: builtins.int
    """"""
    def __init__(
        self,
        *,
        start: builtins.int = ...,
        end: builtins.int = ...,
        biz_type: builtins.int = ...,
        click_button: global___ClickButtonV2 | None = ...,
        text_input: global___TextInputV2 | None = ...,
        check_box: global___CheckBoxV2 | None = ...,
        toast: global___ToastV2 | None = ...,
        bubble: global___BubbleV2 | None = ...,
        label: global___LabelV2 | None = ...,
        post_status: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["bubble", b"bubble", "check_box", b"check_box", "click_button", b"click_button", "label", b"label", "text_input", b"text_input", "toast", b"toast"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["biz_type", b"biz_type", "bubble", b"bubble", "check_box", b"check_box", "click_button", b"click_button", "end", b"end", "label", b"label", "post_status", b"post_status", "start", b"start", "text_input", b"text_input", "toast", b"toast"]) -> None: ...

global___PostPanelV2 = PostPanelV2

@typing_extensions.final
class Response(google.protobuf.message.Message):
    """修改弹幕配置-响应"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    code: builtins.int
    """"""
    message: builtins.str
    """"""
    def __init__(
        self,
        *,
        code: builtins.int = ...,
        message: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "message", b"message"]) -> None: ...

global___Response = Response

@typing_extensions.final
class SubtitleItem(google.protobuf.message.Message):
    """单个字幕信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    ID_STR_FIELD_NUMBER: builtins.int
    LAN_FIELD_NUMBER: builtins.int
    LAN_DOC_FIELD_NUMBER: builtins.int
    SUBTITLE_URL_FIELD_NUMBER: builtins.int
    AUTHOR_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    LAN_DOC_BRIEF_FIELD_NUMBER: builtins.int
    AI_TYPE_FIELD_NUMBER: builtins.int
    AI_STATUS_FIELD_NUMBER: builtins.int
    id: builtins.int
    """字幕id"""
    id_str: builtins.str
    """字幕id str"""
    lan: builtins.str
    """字幕语言代码"""
    lan_doc: builtins.str
    """字幕语言"""
    subtitle_url: builtins.str
    """字幕文件url"""
    @property
    def author(self) -> global___UserInfo:
        """字幕作者信息"""
    type: global___SubtitleType.ValueType
    """字幕类型"""
    lan_doc_brief: builtins.str
    """"""
    ai_type: global___SubtitleAiType.ValueType
    """"""
    ai_status: global___SubtitleAiStatus.ValueType
    """"""
    def __init__(
        self,
        *,
        id: builtins.int = ...,
        id_str: builtins.str = ...,
        lan: builtins.str = ...,
        lan_doc: builtins.str = ...,
        subtitle_url: builtins.str = ...,
        author: global___UserInfo | None = ...,
        type: global___SubtitleType.ValueType = ...,
        lan_doc_brief: builtins.str = ...,
        ai_type: global___SubtitleAiType.ValueType = ...,
        ai_status: global___SubtitleAiStatus.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["author", b"author"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ai_status", b"ai_status", "ai_type", b"ai_type", "author", b"author", "id", b"id", "id_str", b"id_str", "lan", b"lan", "lan_doc", b"lan_doc", "lan_doc_brief", b"lan_doc_brief", "subtitle_url", b"subtitle_url", "type", b"type"]) -> None: ...

global___SubtitleItem = SubtitleItem

@typing_extensions.final
class TextInput(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORTRAIT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    LANDSCAPE_PLACEHOLDER_FIELD_NUMBER: builtins.int
    RENDER_TYPE_FIELD_NUMBER: builtins.int
    PLACEHOLDER_POST_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    POST_STATUS_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    @property
    def portrait_placeholder(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def landscape_placeholder(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    render_type: global___RenderType.ValueType
    """"""
    placeholder_post: builtins.bool
    """"""
    show: builtins.bool
    """"""
    @property
    def avatar(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Avatar]:
        """"""
    post_status: global___PostStatus.ValueType
    """"""
    @property
    def label(self) -> global___Label:
        """"""
    def __init__(
        self,
        *,
        portrait_placeholder: collections.abc.Iterable[builtins.str] | None = ...,
        landscape_placeholder: collections.abc.Iterable[builtins.str] | None = ...,
        render_type: global___RenderType.ValueType = ...,
        placeholder_post: builtins.bool = ...,
        show: builtins.bool = ...,
        avatar: collections.abc.Iterable[global___Avatar] | None = ...,
        post_status: global___PostStatus.ValueType = ...,
        label: global___Label | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["label", b"label"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "label", b"label", "landscape_placeholder", b"landscape_placeholder", "placeholder_post", b"placeholder_post", "portrait_placeholder", b"portrait_placeholder", "post_status", b"post_status", "render_type", b"render_type", "show", b"show"]) -> None: ...

global___TextInput = TextInput

@typing_extensions.final
class TextInputV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PORTRAIT_PLACEHOLDER_FIELD_NUMBER: builtins.int
    LANDSCAPE_PLACEHOLDER_FIELD_NUMBER: builtins.int
    RENDER_TYPE_FIELD_NUMBER: builtins.int
    PLACEHOLDER_POST_FIELD_NUMBER: builtins.int
    AVATAR_FIELD_NUMBER: builtins.int
    TEXT_INPUT_LIMIT_FIELD_NUMBER: builtins.int
    @property
    def portrait_placeholder(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    @property
    def landscape_placeholder(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    render_type: global___RenderType.ValueType
    """"""
    placeholder_post: builtins.bool
    """"""
    @property
    def avatar(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Avatar]:
        """"""
    text_input_limit: builtins.int
    """"""
    def __init__(
        self,
        *,
        portrait_placeholder: collections.abc.Iterable[builtins.str] | None = ...,
        landscape_placeholder: collections.abc.Iterable[builtins.str] | None = ...,
        render_type: global___RenderType.ValueType = ...,
        placeholder_post: builtins.bool = ...,
        avatar: collections.abc.Iterable[global___Avatar] | None = ...,
        text_input_limit: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["avatar", b"avatar", "landscape_placeholder", b"landscape_placeholder", "placeholder_post", b"placeholder_post", "portrait_placeholder", b"portrait_placeholder", "render_type", b"render_type", "text_input_limit", b"text_input_limit"]) -> None: ...

global___TextInputV2 = TextInputV2

@typing_extensions.final
class Toast(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    SHOW_FIELD_NUMBER: builtins.int
    BUTTON_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    duration: builtins.int
    """"""
    show: builtins.bool
    """"""
    @property
    def button(self) -> global___Button:
        """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        duration: builtins.int = ...,
        show: builtins.bool = ...,
        button: global___Button | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["button", b"button"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["button", b"button", "duration", b"duration", "show", b"show", "text", b"text"]) -> None: ...

global___Toast = Toast

@typing_extensions.final
class ToastButtonV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    ACTION_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    action: builtins.int
    """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        action: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "text", b"text"]) -> None: ...

global___ToastButtonV2 = ToastButtonV2

@typing_extensions.final
class ToastV2(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    TOAST_BUTTON_V2_FIELD_NUMBER: builtins.int
    text: builtins.str
    """"""
    duration: builtins.int
    """"""
    @property
    def toast_button_v2(self) -> global___ToastButtonV2:
        """"""
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        duration: builtins.int = ...,
        toast_button_v2: global___ToastButtonV2 | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["toast_button_v2", b"toast_button_v2"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["duration", b"duration", "text", b"text", "toast_button_v2", b"toast_button_v2"]) -> None: ...

global___ToastV2 = ToastV2

@typing_extensions.final
class UserInfo(google.protobuf.message.Message):
    """字幕作者信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SEX_FIELD_NUMBER: builtins.int
    FACE_FIELD_NUMBER: builtins.int
    SIGN_FIELD_NUMBER: builtins.int
    RANK_FIELD_NUMBER: builtins.int
    mid: builtins.int
    """用户mid"""
    name: builtins.str
    """用户昵称"""
    sex: builtins.str
    """用户性别"""
    face: builtins.str
    """用户头像url"""
    sign: builtins.str
    """用户签名"""
    rank: builtins.int
    """用户等级"""
    def __init__(
        self,
        *,
        mid: builtins.int = ...,
        name: builtins.str = ...,
        sex: builtins.str = ...,
        face: builtins.str = ...,
        sign: builtins.str = ...,
        rank: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["face", b"face", "mid", b"mid", "name", b"name", "rank", b"rank", "sex", b"sex", "sign", b"sign"]) -> None: ...

global___UserInfo = UserInfo

@typing_extensions.final
class VideoMask(google.protobuf.message.Message):
    """智能防挡弹幕蒙版信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CID_FIELD_NUMBER: builtins.int
    PLAT_FIELD_NUMBER: builtins.int
    FPS_FIELD_NUMBER: builtins.int
    TIME_FIELD_NUMBER: builtins.int
    MASK_URL_FIELD_NUMBER: builtins.int
    cid: builtins.int
    """视频cid"""
    plat: builtins.int
    """平台
    0:web端 1:客户端
    """
    fps: builtins.int
    """帧率"""
    time: builtins.int
    """间隔时间"""
    mask_url: builtins.str
    """蒙版url"""
    def __init__(
        self,
        *,
        cid: builtins.int = ...,
        plat: builtins.int = ...,
        fps: builtins.int = ...,
        time: builtins.int = ...,
        mask_url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cid", b"cid", "fps", b"fps", "mask_url", b"mask_url", "plat", b"plat", "time", b"time"]) -> None: ...

global___VideoMask = VideoMask

@typing_extensions.final
class VideoSubtitle(google.protobuf.message.Message):
    """视频字幕信息"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAN_FIELD_NUMBER: builtins.int
    LANDOC_FIELD_NUMBER: builtins.int
    SUBTITLES_FIELD_NUMBER: builtins.int
    lan: builtins.str
    """视频原语言代码"""
    lanDoc: builtins.str
    """视频原语言"""
    @property
    def subtitles(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SubtitleItem]:
        """视频字幕列表"""
    def __init__(
        self,
        *,
        lan: builtins.str = ...,
        lanDoc: builtins.str = ...,
        subtitles: collections.abc.Iterable[global___SubtitleItem] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["lan", b"lan", "lanDoc", b"lanDoc", "subtitles", b"subtitles"]) -> None: ...

global___VideoSubtitle = VideoSubtitle



import collections
import time

from .._typing import T_Auth


class Auth(collections.UserDict):
    def __init__(self, auth: T_Auth = None):
        super().__init__()
        self.update({"token": {"tokens": {}}, "cookie": {"cookies": {}}})
        if auth:
            self.update(auth)
        # self.update(kwargs)

    @property
    def uid(self):
        return self["uid"]

    @property
    def tokens_expired(self):
        return self["token"]["expired"]

    @property
    def access_token(self):
        return self["token"]["tokens"].get("access_key")

    @access_token.setter
    def access_token(self, value):
        self["token"]["tokens"]["access_token"] = value

    @property
    def refresh_token(self):
        return self["token"]["tokens"].get("refresh_token")

    @refresh_token.setter
    def refresh_token(self, value):
        self["token"]["tokens"]["refresh_token"] = value

    @property
    def tokens(self):
        return self["token"]["tokens"]

    @property
    def cookies_expired(self):
        return self["cookie"]["expired"]

    @property
    def cookies(self):
        return self["cookie"]["cookies"]

    def refresh_handler(self, data):
        result = {}
        result["origin"] = data
        result["uid"] = data["token_info"]["mid"]
        result["token"] = {}
        result["token"]["expired"] = data["token_info"]["expires_in"] + int(time.time())
        result["token"]["tokens"] = {
            k: v
            for k, v in data["token_info"].items()
            if k in ["access_token", "refresh_token"]
        }
        result["token"]["tokens"]["access_key"] = result["token"]["tokens"][
            "access_token"
        ]
        result["cookie"] = {}
        result["cookie"]["expired"] = data["cookie_info"]["cookies"][0]["expires"]
        result["cookie"]["cookies"] = {
            cookie["name"]: cookie["value"] for cookie in data["cookie_info"]["cookies"]
        }
        return result

    async def refresh(self) -> "Auth":
        from ..login import refresh_token

        resp = await refresh_token(auth=self)
        self.data = self.refresh_handler(resp)
        return self

    async def get_info(self):
        from ..login import get_token_info

        return await get_token_info(self)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _DynamicButtonClickBizType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _DynamicButtonClickBizTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_DynamicButtonClickBizType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DYNAMIC_BUTTON_CLICK_BIZ_TYPE_NONE: _DynamicButtonClickBizType.ValueType  # 0
    """"""
    DYNAMIC_BUTTON_CLICK_BIZ_TYPE_LIVE: _DynamicButtonClickBizType.ValueType  # 1
    """"""
    DYNAMIC_BUTTON_CLICK_BIZ_TYPE_DYN_UP: _DynamicButtonClickBizType.ValueType  # 2
    """"""

class DynamicButtonClickBizType(_DynamicButtonClickBizType, metaclass=_DynamicButtonClickBizTypeEnumTypeWrapper):
    """"""

DYNAMIC_BUTTON_CLICK_BIZ_TYPE_NONE: DynamicButtonClickBizType.ValueType  # 0
""""""
DYNAMIC_BUTTON_CLICK_BIZ_TYPE_LIVE: DynamicButtonClickBizType.ValueType  # 1
""""""
DYNAMIC_BUTTON_CLICK_BIZ_TYPE_DYN_UP: DynamicButtonClickBizType.ValueType  # 2
""""""
global___DynamicButtonClickBizType = DynamicButtonClickBizType

class _ReserveButtonMode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveButtonModeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveButtonMode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESERVE_BUTTON_MODE_NONE: _ReserveButtonMode.ValueType  # 0
    """"""
    RESERVE_BUTTON_MODE_RESERVE: _ReserveButtonMode.ValueType  # 1
    """"""
    RESERVE_BUTTON_MODE_UP_CANCEL: _ReserveButtonMode.ValueType  # 2
    """"""

class ReserveButtonMode(_ReserveButtonMode, metaclass=_ReserveButtonModeEnumTypeWrapper):
    """"""

RESERVE_BUTTON_MODE_NONE: ReserveButtonMode.ValueType  # 0
""""""
RESERVE_BUTTON_MODE_RESERVE: ReserveButtonMode.ValueType  # 1
""""""
RESERVE_BUTTON_MODE_UP_CANCEL: ReserveButtonMode.ValueType  # 2
""""""
global___ReserveButtonMode = ReserveButtonMode

class _ReserveButtonStatus:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ReserveButtonStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ReserveButtonStatus.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    RESERVE_BUTTON_STATUS_NONE: _ReserveButtonStatus.ValueType  # 0
    """"""
    RESERVE_BUTTON_STATUS_UNCHECK: _ReserveButtonStatus.ValueType  # 1
    """"""
    RESERVE_BUTTON_STATUS_CHECK: _ReserveButtonStatus.ValueType  # 2
    """"""

class ReserveButtonStatus(_ReserveButtonStatus, metaclass=_ReserveButtonStatusEnumTypeWrapper):
    """"""

RESERVE_BUTTON_STATUS_NONE: ReserveButtonStatus.ValueType  # 0
""""""
RESERVE_BUTTON_STATUS_UNCHECK: ReserveButtonStatus.ValueType  # 1
""""""
RESERVE_BUTTON_STATUS_CHECK: ReserveButtonStatus.ValueType  # 2
""""""
global___ReserveButtonStatus = ReserveButtonStatus

@typing_extensions.final
class CreateDynReq(google.protobuf.message.Message):
    """创建动态-请求"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    SCENE_FIELD_NUMBER: builtins.int
    PICS_FIELD_NUMBER: builtins.int
    REPOST_SRC_FIELD_NUMBER: builtins.int
    VIDEO_FIELD_NUMBER: builtins.int
    SKETCH_TYPE_FIELD_NUMBER: builtins.int
    SKETCH_FIELD_NUMBER: builtins.int
    PROGRAM_FIELD_NUMBER: builtins.int
    DYN_TAG_FIELD_NUMBER: builtins.int
    ATTACH_CARD_FIELD_NUMBER: builtins.int
    OPTION_FIELD_NUMBER: builtins.int
    TOPIC_FIELD_NUMBER: builtins.int
    UPLOAD_ID_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.UserCreateMeta:
        """用户创建接口meta信息"""
    @property
    def content(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent:
        """发布的内容"""
    scene: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateScene.ValueType
    """发布类型"""
    @property
    def pics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.dynamic.common.dynamic_pb2.CreatePic]:
        """图片内容"""
    @property
    def repost_src(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.DynIdentity:
        """转发源"""
    @property
    def video(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateDynVideo:
        """动态视频"""
    sketch_type: builtins.int
    """通用模板类型：2048方图 2049竖图 其他值无效"""
    @property
    def sketch(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Sketch:
        """通用模板的元内容（网页内容）"""
    @property
    def program(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Program:
        """小程序的内容"""
    @property
    def dyn_tag(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTag:
        """动态附加小卡"""
    @property
    def attach_card(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateAttachCard:
        """动态附加大卡"""
    @property
    def option(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateOption:
        """特殊的创建选项"""
    @property
    def topic(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTopic:
        """"""
    upload_id: builtins.str
    """"""
    def __init__(
        self,
        *,
        meta: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.UserCreateMeta | None = ...,
        content: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent | None = ...,
        scene: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateScene.ValueType = ...,
        pics: collections.abc.Iterable[bilibili.dynamic.common.dynamic_pb2.CreatePic] | None = ...,
        repost_src: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.DynIdentity | None = ...,
        video: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateDynVideo | None = ...,
        sketch_type: builtins.int = ...,
        sketch: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Sketch | None = ...,
        program: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.Program | None = ...,
        dyn_tag: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTag | None = ...,
        attach_card: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateAttachCard | None = ...,
        option: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateOption | None = ...,
        topic: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateTopic | None = ...,
        upload_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["attach_card", b"attach_card", "content", b"content", "dyn_tag", b"dyn_tag", "meta", b"meta", "option", b"option", "program", b"program", "repost_src", b"repost_src", "sketch", b"sketch", "topic", b"topic", "video", b"video"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["attach_card", b"attach_card", "content", b"content", "dyn_tag", b"dyn_tag", "meta", b"meta", "option", b"option", "pics", b"pics", "program", b"program", "repost_src", b"repost_src", "scene", b"scene", "sketch", b"sketch", "sketch_type", b"sketch_type", "topic", b"topic", "upload_id", b"upload_id", "video", b"video"]) -> None: ...

global___CreateDynReq = CreateDynReq

@typing_extensions.final
class CreateInitCheckReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCENE_FIELD_NUMBER: builtins.int
    META_FIELD_NUMBER: builtins.int
    REPOST_FIELD_NUMBER: builtins.int
    scene: builtins.int
    """"""
    @property
    def meta(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.MetaDataCtrl:
        """"""
    @property
    def repost(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.RepostInitCheck:
        """"""
    def __init__(
        self,
        *,
        scene: builtins.int = ...,
        meta: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.MetaDataCtrl | None = ...,
        repost: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.RepostInitCheck | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["meta", b"meta", "repost", b"repost"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["meta", b"meta", "repost", b"repost", "scene", b"scene"]) -> None: ...

global___CreateInitCheckReq = CreateInitCheckReq

@typing_extensions.final
class CreatePageInfosReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic_id", b"topic_id"]) -> None: ...

global___CreatePageInfosReq = CreatePageInfosReq

@typing_extensions.final
class CreatePageInfosRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    @property
    def topic(self) -> global___CreatePageTopicInfo:
        """"""
    def __init__(
        self,
        *,
        topic: global___CreatePageTopicInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic", b"topic"]) -> None: ...

global___CreatePageInfosRsp = CreatePageInfosRsp

@typing_extensions.final
class CreatePageTopicInfo(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_ID_FIELD_NUMBER: builtins.int
    TOPIC_NAME_FIELD_NUMBER: builtins.int
    topic_id: builtins.int
    """"""
    topic_name: builtins.str
    """"""
    def __init__(
        self,
        *,
        topic_id: builtins.int = ...,
        topic_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["topic_id", b"topic_id", "topic_name", b"topic_name"]) -> None: ...

global___CreatePageTopicInfo = CreatePageTopicInfo

@typing_extensions.final
class CreatePermissionButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    type: global___DynamicButtonClickBizType.ValueType
    """"""
    def __init__(
        self,
        *,
        type: global___DynamicButtonClickBizType.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type"]) -> None: ...

global___CreatePermissionButtonClickReq = CreatePermissionButtonClickReq

@typing_extensions.final
class CreatePermissionButtonClickRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreatePermissionButtonClickRsp = CreatePermissionButtonClickRsp

@typing_extensions.final
class CreatePlusButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreatePlusButtonClickReq = CreatePlusButtonClickReq

@typing_extensions.final
class CreatePlusButtonClickRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___CreatePlusButtonClickRsp = CreatePlusButtonClickRsp

@typing_extensions.final
class DynamicButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DynamicButtonClickReq = DynamicButtonClickReq

@typing_extensions.final
class DynamicButtonClickRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___DynamicButtonClickRsp = DynamicButtonClickRsp

@typing_extensions.final
class HotSearchReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___HotSearchReq = HotSearchReq

@typing_extensions.final
class HotSearchRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class Item(google.protobuf.message.Message):
        """"""

        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        WORDS_FIELD_NUMBER: builtins.int
        words: builtins.str
        """"""
        def __init__(
            self,
            *,
            words: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["words", b"words"]) -> None: ...

    ITEMS_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___HotSearchRsp.Item]:
        """"""
    version: builtins.str
    """"""
    def __init__(
        self,
        *,
        items: collections.abc.Iterable[global___HotSearchRsp.Item] | None = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["items", b"items", "version", b"version"]) -> None: ...

global___HotSearchRsp = HotSearchRsp

@typing_extensions.final
class ReserveButtonClickReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UID_FIELD_NUMBER: builtins.int
    RESERVE_ID_FIELD_NUMBER: builtins.int
    RESERVE_TOTAL_FIELD_NUMBER: builtins.int
    CUR_BTN_STATUS_FIELD_NUMBER: builtins.int
    SPMID_FIELD_NUMBER: builtins.int
    DYN_ID_FIELD_NUMBER: builtins.int
    DYN_TYPE_FIELD_NUMBER: builtins.int
    uid: builtins.int
    """"""
    reserve_id: builtins.int
    """"""
    reserve_total: builtins.int
    """"""
    cur_btn_status: builtins.int
    """"""
    spmid: builtins.str
    """"""
    dyn_id: builtins.int
    """"""
    dyn_type: builtins.int
    """"""
    def __init__(
        self,
        *,
        uid: builtins.int = ...,
        reserve_id: builtins.int = ...,
        reserve_total: builtins.int = ...,
        cur_btn_status: builtins.int = ...,
        spmid: builtins.str = ...,
        dyn_id: builtins.int = ...,
        dyn_type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cur_btn_status", b"cur_btn_status", "dyn_id", b"dyn_id", "dyn_type", b"dyn_type", "reserve_id", b"reserve_id", "reserve_total", b"reserve_total", "spmid", b"spmid", "uid", b"uid"]) -> None: ...

global___ReserveButtonClickReq = ReserveButtonClickReq

@typing_extensions.final
class ReserveButtonClickResp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FINAL_BTN_STATUS_FIELD_NUMBER: builtins.int
    BTN_MODE_FIELD_NUMBER: builtins.int
    RESERVE_UPDATE_FIELD_NUMBER: builtins.int
    DESC_UPDATE_FIELD_NUMBER: builtins.int
    HAS_ACTIVITY_FIELD_NUMBER: builtins.int
    ACTIVITY_URL_FIELD_NUMBER: builtins.int
    TOAST_FIELD_NUMBER: builtins.int
    final_btn_status: global___ReserveButtonStatus.ValueType
    """"""
    btn_mode: global___ReserveButtonMode.ValueType
    """"""
    reserve_update: builtins.int
    """"""
    desc_update: builtins.str
    """"""
    has_activity: builtins.bool
    """"""
    activity_url: builtins.str
    """"""
    toast: builtins.str
    """"""
    def __init__(
        self,
        *,
        final_btn_status: global___ReserveButtonStatus.ValueType = ...,
        btn_mode: global___ReserveButtonMode.ValueType = ...,
        reserve_update: builtins.int = ...,
        desc_update: builtins.str = ...,
        has_activity: builtins.bool = ...,
        activity_url: builtins.str = ...,
        toast: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["activity_url", b"activity_url", "btn_mode", b"btn_mode", "desc_update", b"desc_update", "final_btn_status", b"final_btn_status", "has_activity", b"has_activity", "reserve_update", b"reserve_update", "toast", b"toast"]) -> None: ...

global___ReserveButtonClickResp = ReserveButtonClickResp

@typing_extensions.final
class SubmitCheckReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTENT_FIELD_NUMBER: builtins.int
    PICS_FIELD_NUMBER: builtins.int
    @property
    def content(self) -> bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent:
        """"""
    @property
    def pics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[bilibili.dynamic.common.dynamic_pb2.CreatePic]:
        """"""
    def __init__(
        self,
        *,
        content: bilireq.grpc.protos.bilibili.dynamic.common.dynamic_pb2.CreateContent | None = ...,
        pics: collections.abc.Iterable[bilibili.dynamic.common.dynamic_pb2.CreatePic] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "pics", b"pics"]) -> None: ...

global___SubmitCheckReq = SubmitCheckReq

@typing_extensions.final
class SubmitCheckRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SubmitCheckRsp = SubmitCheckRsp

@typing_extensions.final
class SuggestReq(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    S_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    s: builtins.str
    """"""
    type: builtins.int
    """"""
    def __init__(
        self,
        *,
        s: builtins.str = ...,
        type: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["s", b"s", "type", b"type"]) -> None: ...

global___SuggestReq = SuggestReq

@typing_extensions.final
class SuggestRsp(google.protobuf.message.Message):
    """"""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LIST_FIELD_NUMBER: builtins.int
    TRACK_ID_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    @property
    def list(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """"""
    track_id: builtins.str
    """"""
    version: builtins.str
    """"""
    def __init__(
        self,
        *,
        list: collections.abc.Iterable[builtins.str] | None = ...,
        track_id: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["list", b"list", "track_id", b"track_id", "version", b"version"]) -> None: ...

global___SuggestRsp = SuggestRsp
